#!/bin/bash
set -e

if [ "$#" -ne 2 ]; then
    echo "need 2 parameters : python_version and openssl_version"
    echo "example : 3.8.19 3.1.6"
    exit
fi

python_version="$1"
openssl_version="$2"

export LANG=C
rm -Rf /opt/python38/
#rm -Rf Python*
#rm -Rf openssl*
#rm -Rf krb5*
yum install patch byacc autoconf automake libtool pkg-config sqlite-devel.x86_64 libsqlite3x.x86_64 xz-devel lzma bzip2-devel perl-IPC-Cmd -y
#make and install openssl

cd /root
tar -zxvf openssl-${openssl_version}.tar.gz
cd openssl-${openssl_version}
./config --prefix=/opt/python38  -Wl,-rpath,/opt/python38/lib/ --libdir=/opt/python38/lib
make -j`nproc`  >> /root/debug_compile_python 2>&1
make install_sw  >> /root/debug_compile_python 2>&1

#compile p11
cd /root
tar -zxvf libp11-0.4.12.tar.gz
cd libp11-libp11-0.4.12/

chmod a+x /root/patch_p11_attr.patch
patch -p0  ./src/p11_attr.c  < /root/patch_p11_attr.patch

./bootstrap
./configure --prefix=/opt/python38 LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/
make install 

#libffi
cd /root
tar -zxvf libffi-3.4.6.tar.gz 
cd libffi-3.4.6
./configure --prefix=/opt/python38 -C   LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig
make
cp -a */.libs/libffi.so* /opt/python38/lib/
cp -a */.libs/libffi.a /opt/python38/lib/
cp -a */libffi.pc  /opt/python38/lib/pkgconfig/
cp -a ./include/* /opt/python38/include
cp -a ./*/include/* /opt/python38/include


#libpq
cd /root
tar -xvf postgresql-14.12.tar.bz2
cd postgresql-14.12
./configure --prefix=/opt/python38 -C --with-openssl  LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig --without-readline --with-ssl=/opt/python38/lib --with-libraries=/opt/python38/lib --with-includes=/opt/python38/include/
cd src/interfaces/libpq/
make
cp -a libpq.so.* libpq.a /opt/python38/lib
cp -a libpq.pc /opt/python38/lib/pkgconfig

#libnsl
cd /root
tar -xvf libnsl-2.0.1.tar.xz
cd libnsl-2.0.1
./configure --prefix=/opt/python38 -C   LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig
make
cp -a src/.libs/libnsl.so* /opt/python38/lib/
cp -a src/.libs/libnsl.a /opt/python38/lib/


#libreadline
cd /root 
tar -zxvf readline-8.2.tar.gz
cd readline-8.2/
./configure --prefix=/opt/python38 -C   LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig
make
cp -a shlib/libreadline.so.8.2 /opt/python38/lib/
cp -a readline.pc /opt/python38/lib/pkgconfig

#gdbm
cd  /root
tar -zxvf gdbm-1.23.tar.gz
cd gdbm-1.23/
./configure --prefix=/opt/python38 -C   LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig
make
cp ./src/.libs/libgdbm.so.6.0.0 /opt/python38/lib


cd /root
#wget https://www.python.org/ftp/python/${python_version}/Python-${python_version}.tgz
tar -zxvf Python-${python_version}.tgz
cd Python-${python_version}
./configure --prefix=/opt/python38 -C --with-openssl=/opt/python38/ --enable-optimizations --enable-shared LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/
make -j`nproc` install >> /root/debug_compile_python 2>&1
rm -f /opt/python38/bin/{2to3,2to3-3.8,idle3,idle3.8} 

#make and install mit kerberos

cd /root
#wget https://kerberos.org/dist/krb5/1.19/krb5-1.21.2.tar.gz
tar -zxvf krb5-1.21.2.tar.gz
cd krb5-1.21.2/src
./configure  --prefix=/opt/python38 LDFLAGS="-Wl,-rpath,/opt/python38/lib/" PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/ 
make -j`nproc` >> /root/debug_compile_python 2>&1
make install >> /root/debug_compile_python 2>&1
rm -f /opt/python38/bin/{gss-client,k5srvutil,kadmin,kdestroy,kinit,klist,kpasswd,ksu,kswitch,ktutil,kvno,sclient,sim_client,uuclient}
rm -Rf /opt/python38/{sbin,share,var}
rm -Rf /opt/python38/lib/python3.8/test
/opt/python38/bin/python3 -m pip install --upgrade pip
/opt/python38/bin/python3 -m pip install wheel
PKG_CONFIG_PATH=/opt/python38/lib/pkgconfig/ LANG=C LDFLAGS="-L/opt/python38/lib" CFLAGS="-I/opt/python38/include" CPPFLAGS="-I/opt/python38/include/" /opt/python38/bin/python3 -m pip install https://files.pythonhosted.org/packages/68/ce/95b0bae7968c65473e1298efb042e10cafc7bafc14d9e4f154008241c91d/cffi-1.16.0.tar.gz

#/opt/python38/bin/python3 -m pip install whell
#export PATH=$PATH:/opt/python38/bin/ ; /opt/python38/bin/python3 -m pip install -r /root/requirements.txt
exit
